@@ -1,14 +1,14 @@
-.dcFit <- 
-function(data, params, model, inits, n.clones, multiply = NULL, unchanged = NULL, 
-update = NULL, updatefun = NULL, initsfun = NULL, flavour = c("jags", "bugs"), 
-n.chains=3, cl = NULL, parchains = FALSE, ...)
+.dcFit <-
+function(data, params, model, inits, n.clones, multiply = NULL, unchanged = NULL,
+update = NULL, updatefun = NULL, initsfun = NULL, flavour = c("jags", "bugs"),
+n.chains=3, cl = NULL, parchains = FALSE, return.all=FALSE, ...)
 {
     flavour <- match.arg(flavour)
     ## initail evals
     if (missing(n.clones))
         stop("'n.clones' argument must be provided")
-    if (identical(n.clones, 1))
-        stop("'n.clones = 1' gives the Bayesian answer, no need for DC")
+#    if (identical(n.clones, 1))
+#        stop("'n.clones = 1' gives the Bayesian answer, no need for DC")
     if (is.environment(data)) {
         warnings("'data' was environment: it was coerced into a list")
         data <- as.list(data)
@@ -49,7 +49,11 @@ n.chains=3, cl = NULL, parchains = FALSE, ...)
     ## list for dcdiag results
     dcdr <- list()
     ## iteration starts here
-    for (i in 1:times) {
+    if (return.all) {
+        out.all <- vector("list", times)
+        names(out.all) <- paste0("nclones=", k)
+    }
+    for (i in seq_len(times)) {
         tmpch <- if (k[i] == 1) "clone" else "clones"
         if (trace) {
             cat("\nFitting model with", k[i], tmpch, "\n\n")
@@ -71,13 +75,15 @@ n.chains=3, cl = NULL, parchains = FALSE, ...)
             }
         } else {
             if (parchains) {
-                mod <- bugs.parfit(cl, jdat, params, model, inits, 
+                mod <- bugs.parfit(cl, jdat, params, model, inits,
                     n.chains=n.chains, format="mcmc.list", ...)
             } else {
-                mod <- bugs.fit(jdat, params, model, inits, 
+                mod <- bugs.fit(jdat, params, model, inits,
                     n.chains=n.chains, format="mcmc.list", ...)
             }
         }
+        if (return.all)
+            out.all[[i]] <- mod
         ## dctable evaluation
         if (i == 1) {
             vn <- varnames(mod)
@@ -94,7 +100,7 @@ n.chains=3, cl = NULL, parchains = FALSE, ...)
         ## updating
         if (i < times) {
             if (!is.null(update))
-                jdat[[update]] <- if (UPARGS) 
+                jdat[[update]] <- if (UPARGS)
                     updatefun(mod) else updatefun(mod, k[i+1])
             if (!is.null(initsfun))
                 inits <- if (INIARGS)
@@ -111,6 +117,9 @@ n.chains=3, cl = NULL, parchains = FALSE, ...)
             dcts[[j]][i,-1] <- dctmp[j,]
         }
     }
+    ## return list if return.all=TRUE, proceed otherwise
+    if (return.all)
+        return(out.all)
     ## warning if R.hat < crit
     rhat.problem <- any(dctmp[,"r.hat"] >= rhat.crit)
     if (any(is.na(rhat.problem))) {
